Crate dprint_development

Crate dprint_development 

Structs

ParseSpecOptions
RunSpecsOptions
Spec

Constants

RANGE_END
Marks the end of the range to format in a spec’s text.
RANGE_START
Marks the start of the range to format in a spec’s text.

Functions

ensure_no_diagnostics
Checks for diagnostics and panics if it finds any.
parse_specs
run_specs

Type Aliases

SpecConfigMap