Struct dprint_development::RunSpecsOptions [−][src]
Fields
fix_failures: boolSet to true to overwrite the failing tests with the actual result.
format_twice: boolfix_failures: boolSet to true to overwrite the failing tests with the actual result.
format_twice: bool